SoftHyphenPolicy

Enum SoftHyphenPolicy 

pub enum SoftHyphenPolicy {
    Ignore,
    Discretionary,
}
Policy for discretionary soft-hyphen handling.

Variants



Ignore

Treat soft hyphens as invisible and never break on them.



Discretionary

Use soft hyphens as break opportunities and show - when broken.